library(biomaRt)
library(DESeq2)
library(tidyverse)
library(pheatmap)

# -----create annotations----- #
ensembl = useEnsembl("ENSEMBL_MART_ENSEMBL")
ensembl = useMart(biomart="ensembl", dataset="scerevisiae_gene_ensembl")
allannot <- getBM(attributes=c('ensembl_gene_id','external_gene_name','description'), mart = ensembl)
allannot$external_gene_name <- ifelse(allannot$external_gene_name=="", allannot$ensembl_gene_id, allannot$external_gene_name)

# -----load data----- #
data <- read.table("data\\dALLgeneCounts.txt", header=T, row.names=1)
meta <- read.table("metadata\\metadata.txt", header=T, row.names=1)

# -----run mating type analysis----- #
dds <- DESeqDataSetFromMatrix(countData = data, colData = meta, design = ~ batch + genotype + mating_type)
dds <- DESeq(dds)

# -----quality control----- #
rld <- rlog(dds, blind=TRUE)
rld_mat <- assay(rld)
#PCA
plotPCA(rld, intgroup="mating_type")

# -----mating type analysis results----- #
#mating type
contrast <- c("mating_type", "alpha", "a")
res_dds <- lfcShrink(dds, contrast = contrast, type="normal", alpha = 0.05)
summary(res_dds, alpha = 0.05)
res <- res_dds %>% data.frame()
res <- merge(res,allannot, by.x = 'row.names', by.y = 'ensembl_gene_id',all.x=TRUE)
mating_genes <- filter(res,padj<0.05)

#write.table(res, "results/mating_type_analysis.txt", sep = "\t", row.names = FALSE, col.names = TRUE)
#write.table(mating_genes, "results/mating_genes.txt", sep = "\t", row.names = FALSE, col.names = TRUE)

#remove genes related to mating type
rownames(mating_genes) <- mating_genes[,1]
mating_genes <- mating_genes[,-1]
data <- data[which(!rownames(data) %in% rownames(mating_genes)), ]

# -----run analysis----- #
dds <- DESeqDataSetFromMatrix(countData = data, colData = meta, design = ~batch + genotype)
dds <- DESeq(dds)

# -----quality control----- #
rld <- rlog(dds, blind=TRUE)
rld_mat <- assay(rld)

#PCA
plotPCA(rld, intgroup="mating_type")
plotPCA(rld, intgroup="batch")
plotPCA(rld, intgroup="marker")
plotPCA(rld, intgroup="genotype")

#clustering
rld_cor <- cor(rld_mat)
pheatmap(rld_cor)

#plot dispersion estimates
plotDispEsts(dds)

# -----results----- #
for (mutant in c('caf130','cal4','btt1','egd1','btt1egd1','egd2','acl4')){
  contrast <- c("genotype", mutant, "_WT")
  res_dds <- lfcShrink(dds, contrast = contrast, type="normal", alpha = 0.05)
  res <- res_dds %>% data.frame()
  res <- merge(res,allannot, by.x = 'row.names', by.y = 'ensembl_gene_id',all.x=TRUE)
  write.table(res, paste0("results/",mutant,"_vs_WT.txt"), sep = "\t", row.names = FALSE, col.names = TRUE)
}
